// @flow

import React from 'react'
import cn from 'classnames'
import { themr } from 'react-css-themr'
import interpolate from 'interpolate'
import Image from 'components/Image'

type Props = {
  items: {
    image?: TCloudinaryImage,
    src?: string,
    alt?: string,
    title?: string,
  }[],
  largeCount?: number,
  smallCount?: number,
  showMoreMessage?: string,
  onSelect?: Function,
  onShowMore?: Function,
  theme: *,
}

function ImageList({
  items,
  largeCount = 2,
  smallCount = 3,
  showMoreMessage = '{count}+',
  onSelect,
  onShowMore,
  theme,
}: Props) {
  const largeItems = items.slice(0, largeCount)
  const smallItems = items.slice(largeCount, smallCount + largeCount)
  return (
    <div className={theme.root}>
      {largeItems.length > 0 && (
        <div className={theme.largeList}>
          {largeItems.map((x, idx) => (
            <div className={theme.largeWrapper} key={idx}>
              <div
                className={theme.largeImage}
                onClick={() => onSelect && onSelect(idx)}
              >
                <Image className="absolute w-100 h-100" {...x} />
              </div>
            </div>
          ))}
        </div>
      )}
      {smallItems.length > 0 && (
        <div className={theme.smallList}>
          {smallItems.map((x, idx) => (
            <div className={theme.smallWrapper} key={idx}>
              <div
                className={theme.smallImage}
                onClick={() => {
                  if (onShowMore) onShowMore(largeCount + 1)
                  else if (onSelect) onSelect(largeCount + idx)
                }}
              >
                <Image className="absolute w-100 h-100" {...x} />
                {idx === smallItems.length - 1 && (
                  <div
                    className={cn(
                      'absolute w-100 h-100',
                      theme.showMoreOverlay,
                    )}
                  >
                    <span className={theme.showMore}>
                      {interpolate(showMoreMessage, { count: items.length })}
                    </span>
                  </div>
                )}
              </div>
            </div>
          ))}
        </div>
      )}
    </div>
  )
}

export default themr('ImageList', {}, { composeTheme: 'softly' })(ImageList)
